@@ -33,10 +33,11 @@
 #  define MOLEQUEUESERVERCORE_DEPRECATED_NO_EXPORT MOLEQUEUESERVERCORE_NO_EXPORT MOLEQUEUESERVERCORE_DEPRECATED
 #endif
 
+/* NOLINTNEXTLINE(readability-avoid-unconditional-preprocessor-if) */
 #if 0 /* DEFINE_NO_DEPRECATED */
 #  ifndef MOLEQUEUESERVERCORE_NO_DEPRECATED
 #    define MOLEQUEUESERVERCORE_NO_DEPRECATED
 #  endif
 #endif
 
-#endif
+#endif /* MOLEQUEUESERVERCORE_EXPORT_H */
